@@ -11,7 +11,7 @@ Business::Fixflo - Perl library for interacting with the Fixflo API
 
 =head1 VERSION
 
-0.14
+0.15
 
 =head1 DESCRIPTION
 
@@ -187,15 +187,20 @@ has client => (
 
     issues
     agencies
+    landlords
     properties
     property_addresses
     issue
+    issue_draft
+    issue_draft_media
+    landlord
+    landlord_property
     agency
     property
     property_address
     quick_view_panels
 
-Get a [list of] issue(s) / agenc(y|ies) / propert(y|ies) / property address(es):
+Get a [list of] issue(s) / agenc(y|ies) / propert(y|ies) / property address(es) / landlord(s) / landlord_property:
 
     my $paginator = $ff->issues( %query_params );
 
@@ -227,6 +232,19 @@ external reference:
 
     my $Property = $ff->property( 'P123',1 );
 
+Note the landlord method can take a flag to indicate that the passed $id is an
+email address
+
+    my $Landlord = $ff->landlord( 'leejo@cpan.org',1 );
+
+Note the landlord_property method can take two arguments, it only one is passed
+this is taken as the LandlordPropertyId, if two arguments are passed they are
+taken as the LandlordId and the PropertyId:
+
+    my $LandlordProperty = $ff->landlord_property( $landlord_property_id );
+
+    my $LandlordProperty = $ff->landlord_property( $landlord_id,$property_id );
+
 =cut
 
 sub issues {
@@ -244,6 +262,11 @@ sub properties {
     return $self->client->_get_properties( \%params );
 }
 
+sub landlords {
+    my ( $self,%params ) = @_;
+    return $self->client->_get_landlords( \%params );
+}
+
 sub property_addresses {
     my ( $self,%params ) = @_;
     return $self->client->_get_property_addresses( \%params );
@@ -254,6 +277,16 @@ sub issue {
     return $self->client->_get_issue( $id );
 }
 
+sub issue_draft {
+    my ( $self,$id ) = @_;
+    return $self->client->_get_issue_draft( $id );
+}
+
+sub issue_draft_media {
+    my ( $self,$id ) = @_;
+    return $self->client->_get_issue_draft_media( $id );
+}
+
 sub agency {
     my ( $self,$id ) = @_;
     return $self->client->_get_agency( $id );
@@ -264,6 +297,16 @@ sub property {
     return $self->client->_get_property( $id,$is_external_id );
 }
 
+sub landlord {
+    my ( $self,$id,$is_external_id ) = @_;
+    return $self->client->_get_landlord( $id,$is_external_id );
+}
+
+sub landlord_property {
+    my ( $self,$id_or_landlord_id,$property_id ) = @_;
+    return $self->client->_get_landlord_property( $id_or_landlord_id,$property_id );
+}
+
 sub property_address {
     my ( $self,$id ) = @_;
     return $self->client->_get_property_address( $id );
@@ -290,6 +333,14 @@ L<Business::Fixflo::Client>
 
 L<Business::Fixflo::Issue>
 
+L<Business::Fixflo::IssueDraft>
+
+L<Business::Fixflo::IssueDraftMedia>
+
+L<Business::Fixflo::Landlord>
+
+L<Business::Fixflo::LandlordProperty>
+
 L<Business::Fixflo::Paginator>
 
 L<Business::Fixflo::Property>
